==> haskell-hopenpgp-2.5.5-38-i686.pkg.tar.xz: usr/share/haskell/register/haskell-hopenpgp.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hOpenPGP
version: 2.5.5
id: hOpenPGP-2.5.5-SGuiePwT8WAcOm8NdnNPD
key: hOpenPGP-2.5.5-SGuiePwT8WAcOm8NdnNPD
license: MIT
copyright: 2012-2016  Clint Adams
maintainer: Clint Adams <clint@debian.org>
homepage: http://floss.scru.org/hOpenPGP/
synopsis: native Haskell implementation of OpenPGP (RFC4880)
description:
    native Haskell implementation of OpenPGP (RFC4880), plus Camellia (RFC5581)
category: Codec, Data
author: Clint Adams
exposed: True
exposed-modules:
    Codec.Encryption.OpenPGP.Types Codec.Encryption.OpenPGP.CFB
    Codec.Encryption.OpenPGP.Compression
    Codec.Encryption.OpenPGP.Expirations
    Codec.Encryption.OpenPGP.Fingerprint
    Codec.Encryption.OpenPGP.KeyInfo
    Codec.Encryption.OpenPGP.KeyringParser
    Codec.Encryption.OpenPGP.KeySelection
    Codec.Encryption.OpenPGP.Ontology Codec.Encryption.OpenPGP.S2K
    Codec.Encryption.OpenPGP.SecretKey
    Codec.Encryption.OpenPGP.Serialize
    Codec.Encryption.OpenPGP.Signatures
    Data.Conduit.OpenPGP.Compression Data.Conduit.OpenPGP.Decrypt
    Data.Conduit.OpenPGP.Filter Data.Conduit.OpenPGP.Keyring
    Data.Conduit.OpenPGP.Keyring.Instances Data.Conduit.OpenPGP.Verify
hidden-modules: Codec.Encryption.OpenPGP.Internal
                Codec.Encryption.OpenPGP.Internal.CryptoCipherTypes
                Codec.Encryption.OpenPGP.Internal.Cryptonite
                Codec.Encryption.OpenPGP.Internal.HOBlockCipher
                Codec.Encryption.OpenPGP.SerializeForSigs
                Codec.Encryption.OpenPGP.Types.Internal.Base
                Codec.Encryption.OpenPGP.Types.Internal.CryptoniteNewtypes
                Codec.Encryption.OpenPGP.Types.Internal.PacketClass
                Codec.Encryption.OpenPGP.Types.Internal.PKITypes
                Codec.Encryption.OpenPGP.Types.Internal.Pkt
                Codec.Encryption.OpenPGP.Types.Internal.TK
                Codec.Encryption.OpenPGP.BlockCipher
abi: fe116da0e31737da1011a79105d69a76
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/hOpenPGP-2.5.5
library-dirs: /usr/lib/ghc-8.0.1/site-local/hOpenPGP-2.5.5
data-dir: /usr/share/i386-linux-ghc-8.0.1/hOpenPGP-2.5.5
hs-libraries: HShOpenPGP-2.5.5-SGuiePwT8WAcOm8NdnNPD
depends:
    aeson-1.0.2.1-9juLbWuUPUaFK1txzTGd5H
    attoparsec-0.13.1.0-4MHT8pBlPVm5gUqsk1oQRa base-4.9.0.0
    base16-bytestring-0.1.1.6-5dPoF8dzhwzBaEB2MvnmIS
    base64-bytestring-1.0.0.1-In9M41tLtcS9QYt3QpGpNY
    bifunctors-5.4.1-DfVkdtHpKE8vmoB9WwpVO binary-0.8.3.0
    binary-conduit-1.2.4.1-6ejy34d6YIL7muuw3SSSfO
    byteable-0.1.1-15aIBCArSOBEnGxArzrDTM bytestring-0.10.8.1
    bzlib-0.5.0.5-LhSa8mr35TvLPPGKdeRJgk
    conduit-1.2.9-IqfCpUleYsf85Inkwdla2
    conduit-extra-1.1.15-KZxjNLiGvO99hnZb2u51Yl containers-0.5.7.1
    crypto-cipher-types-0.0.9-CQo1wjK4MahLTgPPIvkKhR
    cryptonite-0.22-7bAfM4r9KLCJIhVfr7jYAd
    data-default-class-0.1.2.0-6eetmQ6CbQOLoXb6k5kODu
    errors-2.1.3-8ITYmxCImbF1o6OlWIOTbu
    hashable-1.2.6.0-En2FSYN34Tp8YO8pqagtg1
    incremental-parser-0.2.5-23ZMt5mNKnt9cnxXll9wkR
    ixset-typed-0.3.1-LJZ2wxllu2rDE1hXKdphSz
    lens-4.15.1-AXftRhVcDpjE055oLJWaDH
    memory-0.14.2-6gBSLDcT37k2vocvCRPqMi
    monad-loops-0.4.3-2fzM5iYl9mFG5pm27bHqMF
    nettle-0.2.0-63JRKZfXMrqIi47fKlHIzn
    network-2.6.3.1-G4Up1CPKbp7DeFsnywOnGG
    network-uri-2.6.1.0-8yR4gjnzE4eDGhJR7PHfVJ
    newtype-0.2-6DnlyeREupYF8x0b7VMCgm
    openpgp-asciiarmor-0.1-Em0eyanSnJ9iZY9FWcYMe
    resourcet-1.1.9-CymaqmR8zCeCrSnerfb4Fa
    securemem-0.1.9-KeNPeBwEbEJKdZ1VAGsGdP
    semigroups-0.18.2-2lmUSJvrDkM6JBURGRclWz
    split-0.2.3.1-IJKK4pOCYGKud0jZImZke
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ time-1.6.0.1
    time-locale-compat-0.1.1.3-1j5dGjxxtiTDuAsO86iSk0
    transformers-0.5.2.0
    unordered-containers-0.2.8.0-HozSxlbOa6oDZVsS46CFCU
    wl-pprint-extras-3.5.0.5-5YqPlIKC0qJ3RJzdeBOWKh
    zlib-0.6.1.2-1dMv6Gv8Q4W22Ei4thcEsU
haddock-interfaces: /usr/share/doc/haskell-hopenpgp/html/hOpenPGP.haddock
haddock-html: /usr/share/doc/haskell-hopenpgp/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hopenpgp-2.5.5-44-i686.pkg.tar.xz: usr/share/haskell/register/haskell-hopenpgp.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hOpenPGP
version: 2.5.5
id: hOpenPGP-2.5.5-BrStFpE7wnv6HONu00AlCz
key: hOpenPGP-2.5.5-BrStFpE7wnv6HONu00AlCz
license: MIT
copyright: 2012-2016  Clint Adams
maintainer: Clint Adams <clint@debian.org>
homepage: http://floss.scru.org/hOpenPGP/
synopsis: native Haskell implementation of OpenPGP (RFC4880)
description:
    native Haskell implementation of OpenPGP (RFC4880), plus Camellia (RFC5581)
category: Codec, Data
author: Clint Adams
exposed: True
exposed-modules:
    Codec.Encryption.OpenPGP.Types Codec.Encryption.OpenPGP.CFB
    Codec.Encryption.OpenPGP.Compression
    Codec.Encryption.OpenPGP.Expirations
    Codec.Encryption.OpenPGP.Fingerprint
    Codec.Encryption.OpenPGP.KeyInfo
    Codec.Encryption.OpenPGP.KeyringParser
    Codec.Encryption.OpenPGP.KeySelection
    Codec.Encryption.OpenPGP.Ontology Codec.Encryption.OpenPGP.S2K
    Codec.Encryption.OpenPGP.SecretKey
    Codec.Encryption.OpenPGP.Serialize
    Codec.Encryption.OpenPGP.Signatures
    Data.Conduit.OpenPGP.Compression Data.Conduit.OpenPGP.Decrypt
    Data.Conduit.OpenPGP.Filter Data.Conduit.OpenPGP.Keyring
    Data.Conduit.OpenPGP.Keyring.Instances Data.Conduit.OpenPGP.Verify
hidden-modules: Codec.Encryption.OpenPGP.Internal
                Codec.Encryption.OpenPGP.Internal.CryptoCipherTypes
                Codec.Encryption.OpenPGP.Internal.Cryptonite
                Codec.Encryption.OpenPGP.Internal.HOBlockCipher
                Codec.Encryption.OpenPGP.SerializeForSigs
                Codec.Encryption.OpenPGP.Types.Internal.Base
                Codec.Encryption.OpenPGP.Types.Internal.CryptoniteNewtypes
                Codec.Encryption.OpenPGP.Types.Internal.PacketClass
                Codec.Encryption.OpenPGP.Types.Internal.PKITypes
                Codec.Encryption.OpenPGP.Types.Internal.Pkt
                Codec.Encryption.OpenPGP.Types.Internal.TK
                Codec.Encryption.OpenPGP.BlockCipher
abi: fe6cdff6d23a14a3e738b03cd5113dfc
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/hOpenPGP-2.5.5
library-dirs: /usr/lib/ghc-8.0.1/site-local/hOpenPGP-2.5.5
data-dir: /usr/share/i386-linux-ghc-8.0.1/hOpenPGP-2.5.5
hs-libraries: HShOpenPGP-2.5.5-BrStFpE7wnv6HONu00AlCz
depends:
    aeson-1.0.2.1-3Jq86jEoa9M6oFiloBG3wo
    attoparsec-0.13.1.0-2DLGgk6uYI0KCQbpcUzmmN base-4.9.0.0
    base16-bytestring-0.1.1.6-5dPoF8dzhwzBaEB2MvnmIS
    base64-bytestring-1.0.0.1-In9M41tLtcS9QYt3QpGpNY
    bifunctors-5.4.1-Ac6G6TmMVPE36jXOz0jDKq binary-0.8.3.0
    binary-conduit-1.2.4.1-7Q3nAeBQb4XEsZUzozu8ee
    byteable-0.1.1-15aIBCArSOBEnGxArzrDTM bytestring-0.10.8.1
    bzlib-0.5.0.5-LhSa8mr35TvLPPGKdeRJgk
    conduit-1.2.9.1-GZZC8SxHl2s2gE2ucPFZOM
    conduit-extra-1.1.15-FtUK8gS5pnWC2gXavC0Bx7 containers-0.5.7.1
    crypto-cipher-types-0.0.9-Gaasy8ZWU3y7kxB46txgJY
    cryptonite-0.22-FrA8V8Abapg2T1hBQpVkR5
    data-default-class-0.1.2.0-6eetmQ6CbQOLoXb6k5kODu
    errors-2.1.3-8ITYmxCImbF1o6OlWIOTbu
    hashable-1.2.6.0-En2FSYN34Tp8YO8pqagtg1
    incremental-parser-0.2.5-4m29DibcxbxAhlcLYlnkjf
    ixset-typed-0.3.1-3enAfzK2vSn3UjLhkzNdBn
    lens-4.15.1-IUiPLudMeha4y54hlYjYR3
    memory-0.14.3-9wQQTseliVGKJ09laFleog
    monad-loops-0.4.3-2fzM5iYl9mFG5pm27bHqMF
    nettle-0.2.0-54MsI4KSmNQFBnQ0PgRfAi
    network-2.6.3.1-G4Up1CPKbp7DeFsnywOnGG
    network-uri-2.6.1.0-8yR4gjnzE4eDGhJR7PHfVJ
    newtype-0.2-6DnlyeREupYF8x0b7VMCgm
    openpgp-asciiarmor-0.1-EsYHv0NvUKbCZmv7cDx4lM
    resourcet-1.1.9-CymaqmR8zCeCrSnerfb4Fa
    securemem-0.1.9-E3A92GFzWR8Jl7bHNv7cPG
    semigroups-0.18.2-2lmUSJvrDkM6JBURGRclWz
    split-0.2.3.1-IJKK4pOCYGKud0jZImZke
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ time-1.6.0.1
    time-locale-compat-0.1.1.3-1j5dGjxxtiTDuAsO86iSk0
    transformers-0.5.2.0
    unordered-containers-0.2.8.0-HozSxlbOa6oDZVsS46CFCU
    wl-pprint-extras-3.5.0.5-6FTsZr1T9i19b2waRkYhHW
    zlib-0.6.1.2-1dMv6Gv8Q4W22Ei4thcEsU
haddock-interfaces: /usr/share/doc/haskell-hopenpgp/html/hOpenPGP.haddock
haddock-html: /usr/share/doc/haskell-hopenpgp/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
